@@ -707,9 +707,7 @@ class WithDynamicSerializerMixin(
             id_field = self.fields[id_attr]
             id_value = id_field.get_value(data)
             value[id_attr] = id_value
-        #This statement is being commented as validation for nested object didn't work if returned value
-        # return value
-        return data
+        return value
 
     def save(self, *args, **kwargs):
         """Serializer save that address prefetch issues."""
